@@ -30,6 +30,7 @@
 
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-gtk-compat.h>
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
@@ -41,15 +42,6 @@
 #include "prefs.h"
 #include "gfx.h"
 
-#ifdef GGZ_CLIENT
-#include <libgames-support/games-dlg-chat.h>
-#include <libgames-support/games-dlg-players.h>
-#include "connectx_client.h"
-#include "ggz-network.h"
-#include <ggz-embed.h>
-#endif
-
-
 #define SPEED_MOVE     25
 #define SPEED_DROP     20
 #define SPEED_BLINK    150
@@ -144,8 +136,8 @@ static gint
 get_n_human_players (void)
 {
   if (ggz_network_mode)
-    return 2;			/* FIXME */
-
+    return 2;
+  
   if (p.level[PLAYER1] != LEVEL_HUMAN && p.level[PLAYER2] != LEVEL_HUMAN) {
     return 0;
   }
@@ -160,9 +152,6 @@ get_n_human_players (void)
 static gboolean
 is_player_human (void)
 {
-  if (ggz_network_mode)
-    return TRUE;		/* FIXME */
-
   if (player == PLAYER1) {
     return p.level[PLAYER1] == LEVEL_HUMAN;
   }
@@ -571,11 +560,6 @@ prompt_player (void)
     return;
   }
 
-/*	if (ggz_network_mode) {
-		network_update_status ();
-		return;
-	}*/
-
   switch (players) {
   case 1:
     if (human) {
@@ -823,15 +807,15 @@ on_game_scores (GtkMenuItem * m, gpointer data)
   gtk_dialog_set_has_separator (GTK_DIALOG (scorebox), FALSE);
   gtk_window_set_resizable (GTK_WINDOW (scorebox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (scorebox), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (scorebox)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (scorebox))), 2);
 
   g_signal_connect (GTK_OBJECT (scorebox), "destroy",
 		    G_CALLBACK (gtk_widget_destroyed), &scorebox);
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (scorebox)->vbox), vbox, TRUE, TRUE,
-		      0);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (scorebox))),
+		      vbox, TRUE, TRUE, 0);
 
   icon = gtk_image_new_from_icon_name ("gnome-gnect", 48);
   gtk_box_pack_start (GTK_BOX (vbox), icon, FALSE, FALSE, 0);
